@echo off
echo Extract QMORPH Global Precipitation
echo Rolling archive of about two weeks
echo Precipitation in mm/hr
echo File name format QMORPH_8km_2011112823.Z
echo Two layers extracted
echo Layer 1 = next half hour after the time stamp used
echo Layer 2 = previous half hour with regard to the time stamp used
echo.
echo.

set longfilename=%1
set shortfilename1=%longfilename:~0,10%

set InputDrive=%2
set InputDir=%3
set OutputDrive=%4
set OutputDir=%5
set gdalDir=%6
set IlwDir=%7
set UtilDir=%8


cd\
%OutputDrive%
cd %OutputDir%


echo your current working directory = %OutputDrive%\%OutputDir%
echo.
echo.

"%UtilDir%\wget\wget.exe" ftp://ftp.cpc.ncep.noaa.gov/precip/qmorph/30min_8km/QMORPH_8km_%shortfilename1%.Z



echo off
if not exist "%OutputDrive%\%OutputDir%\QMORPH_8km_%shortfilename1%.Z"  goto MESSAGE
echo The file(s) "QMORPH_8km_%shortfilename1%.Z" has been retrieved and transferred to your current working directory
echo.
echo.

GOTO START

:MESSAGE
echo The input file was not found in the archive.
echo Check your Date stamp settings
echo Your current Date stamp used is %shortfilename1%
echo Data is retrieved from ftp://ftp.cpc.ncep.noaa.gov/precip/qmorph/30min_8km
echo Check also manually if the data exists on ftp archive (see link above)
echo Internet has a transient nature - addresses might not be valid or has changed after some time!


pause

GOTO END

:START


"%UtilDir%\7z.exe" e QMORPH_8km_%shortfilename1%.Z

ren QMORPH_8km_%shortfilename1% tqmorph8km30min_%shortfilename1%

rem import as maplist

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%.mpl:=maplist('%OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%',genras,Convert,4948,6,0,BSQ,Byte,1,NoSwap,CreateMpr)

rem delete unnecessary layers and maplist

del tqmorph8km30min_%shortfilename1%
del tqmorph8km30min_%shortfilename1%.mpl
del tqmorph8km30min_%shortfilename1%2.mp* 
del tqmorph8km30min_%shortfilename1%3.mp* 
del tqmorph8km30min_%shortfilename1%5.mp* 
del tqmorph8km30min_%shortfilename1%6.mp* 

rem create subset maps

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%1_east.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%1',1,1,1649,2474)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%1_west.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%1',1,2475,1649,2474)

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%4_east.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%4',1,1,1649,2474)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%4_west.mpr:=MapSubMap('%OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%4',1,2475,1649,2474)

rem add submap georef

"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%1_east.mpr %UtilDir%\cmorph_east
"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%1_west.mpr %UtilDir%\cmorph_west

"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%4_east.mpr %UtilDir%\cmorph_east
"%IlwDir%\ilwis.exe" -C setgrf %OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%4_west.mpr %UtilDir%\cmorph_west

rem glue maps using georef global

"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%1_recomposed.mpr:=MapGlue('%UtilDir%\cmorph_8km'.grf,%OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%1_west,%OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%1_east,replace)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%4_recomposed.mpr:=MapGlue('%UtilDir%\cmorph_8km'.grf,%OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%4_west,%OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%4_east,replace)


"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\qmorph8km30min_%shortfilename1%later:=iff(%OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%1_recomposed lt 255,%OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%1_recomposed*0.2,?)
"%IlwDir%\ilwis.exe" -C %OutputDrive%\%OutputDir%\qmorph8km30min_%shortfilename1%before:=iff(%OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%4_recomposed lt 255,%OutputDrive%\%OutputDir%\tqmorph8km30min_%shortfilename1%4_recomposed*0.2,?)


rem delete obsolete objects

del QMORPH_8km_%shortfilename1%.Z
del tqmorph8km30min*.mp*


:END
"%IlwDir%\ilwis.exe" -C closeall